@@ -668,183 +668,179 @@ def metadata_extraction (df_users):
 
 def text_tweets_features_extraction(data_tweets):
    
-    seasonalityDF = []
-    tweets_urlDF = []
-    mentionsDF = []
-    text_tweetsDF = []
-    fav_twDF= []
-    ret_twDF = []
-    ret_twDF_list = []
-    fav_twDF_list = []
-    ntwPro_DF= []
-    RT_tw = []
-    minu_tw = []
-    minu_tw_answer = []
-    tw_duplicated = []
-    duplicated = []
-    tw_per_day_list= []
-    screen_name_mention_user = []
-    tweets = []
-    tweets_url = 0
-    num_tw_day = 0
-    is_RT=0
-    is_RT_list= []
-    screen_name_mention = []
-    RT = []
-    retweet_list = []
-    favorite_list = []
-    mentions = 0
-    time_btw_tw = []
-    tw_answer = []
-    num_tw_days = []
-    text_duplicated = []
-    tw_day_list = []
-    text_tweets_day = []
-    text_tweets_days = []
-    text_tweets_days_list = []
-    #Almacenar la fecha entera de los tweets para si hay que consultar las horas de ese dia
-    tweet_date_day = []
-    tweet_date_days = []
-    tweet_date_days_list = []
-    lang_text_tweet = list(data_tweets["lang_tw"])
-    text_tweets_user= list(data_tweets["text"])
-    print(len(text_tweets_user))
-    favorites= list(data_tweets["favorites"])
-    retweets = list(data_tweets["retweets"])
-    tweets_date= pd.to_datetime(data_tweets["created_at_tw"])
-    for j in range(len(text_tweets_user)): #Comprobamos cuantos tweets han sido escritos por el usuario 
-        if(text_tweets_user[j].startswith('RT',0)):
-            RT.append(text_tweets_user[j])
-            is_RT = 1
-        else:
-            is_RT=0          
-            #Tweets with url from users
-            if "http" in text_tweets_user[j]:
-                tweets_url = tweets_url + 1
-            #Tweets with mentions from users
-            if "@" in text_tweets_user[j]:
-                mentions = mentions + 1                        
-            else:
-                #Time of the answer of a tweet(tw --> @)
-                if(j!=(len(text_tweets_user)-1)):
-                    if ("@" in text_tweets_user[j+1]):
-                        tw_answer.append((tweets_date[j] - tweets_date[j+1]) / np.timedelta64(1,'m'))
-                #Found duplicated tweets where the only change the photo  that the users publish
-                text_sinHttp = " ".join(filter(lambda x:x[0:4]!='http', text_tweets_user[j].split()))
-                text_sinMencion = " ".join(filter(lambda x:x[0]!='@', text_sinHttp.split()))
-                text_duplicated.append(text_sinMencion)
-            tweets.append({"text":text_tweets_user[j], "lang": lang_text_tweet[j], "RT": 0})
-            retweet_list.append(int(retweets[j]))
-            favorite_list.append(int(favorites[j]))
-        is_RT_list.append(is_RT)                                
-        if(j!=0):
-          #Time between tweets (RT + propios)
-          time_btw_tw.append((tweets_date[j-1] - tweets_date[j]) / np.timedelta64(1,'m'))
-          #Found if tweets are the same day
-          #Second condition if all the tweets are the same day          
-          if((tweets_date[j-1].date() == tweets_date[j].date()) & (j!=(len(text_tweets_user)-1))):
-                            
-              num_tw_day = num_tw_day + 1
-              #Create a list with the tweets of a day
-              text_tweets_day.append({"text": text_tweets_user[j-1],"lang": lang_text_tweet[j-1],"RT": is_RT_list[j-1]})
-              text_tweets_day.append({"text": text_tweets_user[j],"lang": lang_text_tweet[j], "RT": is_RT_list[j]})              
-              tweet_date_day.append(tweets_date[j-1])
-              tweet_date_day.append(tweets_date[j])                         
-          else:
-              if(j==(len(text_tweets_user)-1)):                  
-                  if(tweets_date[j-1].date() == tweets_date[j].date()):                     
-                      text_tweets_day.append({"text": text_tweets_user[j-1],"lang": lang_text_tweet[j-1],"RT": is_RT_list[j-1]})
-                      text_tweets_day.append({"text": text_tweets_user[j],"lang": lang_text_tweet[j], "RT": is_RT_list[j]})              
-                      tweet_date_day.append(tweets_date[j-1])
-                      tweet_date_day.append(tweets_date[j])
-                      num_tw_day = num_tw_day + 1
-                      num_tw_days.append(num_tw_day)
-                      text_tweets_days.append([i for n, i in enumerate(text_tweets_day) if i not in text_tweets_day[n + 1:]] )
-                      tweet_date_days.append(list(dict.fromkeys(tweet_date_day)))
-                      num_tw_day = 1 
-                      text_tweets_day = []
-                      tweet_date_day = []
-                  else:                      
-                      text_tweets_day.append({"text": text_tweets_user[j-1],"lang": lang_text_tweet[j-1],"RT": is_RT_list[j-1]})                                   
-                      tweet_date_day.append(tweets_date[j-1]) 
-                      num_tw_days.append(1)                     
-                      text_tweets_days.append([i for n, i in enumerate(text_tweets_day) if i not in text_tweets_day[n + 1:]])
-                      tweet_date_days.append(list(dict.fromkeys(tweet_date_day)))
-                      text_tweets_day = []
-                      tweet_date_day = []
-                      
-                      tweet_date_day.append(tweets_date[j])                     
-                      text_tweets_day.append({"text": text_tweets_user[j],"lang": lang_text_tweet[j], "RT": is_RT_list[j]}) 
-                      num_tw_days.append(1)
-                      text_tweets_days.append([i for n, i in enumerate(text_tweets_day) if i not in text_tweets_day[n + 1:]] )
-                      tweet_date_days.append(list(dict.fromkeys(tweet_date_day)))
-                      num_tw_day = 1 
-                      text_tweets_day = []
-                      tweet_date_day = []
-                      
-              else:
-                  if(num_tw_day ==1):
-                    text_tweets_day.append({"text": text_tweets_user[j-1],"lang": lang_text_tweet[j-1],"RT": is_RT_list[j-1]})
-                    tweet_date_day.append(tweets_date[j-1])
-                  #+1 because dont sum the last interation
-                  num_tw_days.append(num_tw_day)
-                  text_tweets_days.append([i for n, i in enumerate(text_tweets_day) if i not in text_tweets_day[n + 1:]] )
-                  tweet_date_days.append(list(dict.fromkeys(tweet_date_day)))           
-                  num_tw_day = 1 
-                  text_tweets_day = []
-                  tweet_date_day = []
-        if "@" in (text_tweets_user[j]):
-            split_text = text_tweets_user[j].split()
-            check = "@"
-            screen_name_mention1 = [idx for idx in split_text if idx.lower().startswith(check.lower())] 
-            if not screen_name_mention1:
-                    screen_name_mention.append(["Empty"])
-            else:
-                screen_name_mention1 = re.sub("[\[\]\'\"!@?¿#$:….,]", '',str(screen_name_mention1)).split(", ")
-                if(text_tweets_user[j].startswith('RT',0)):
-                    screen_name_mention.append([screen_name_mention1[0]])                    
-                else:
-                    screen_name_mention.append(screen_name_mention1)
-        else:
-            screen_name_mention.append(["Empty"])
+	seasonalityDF = []
+	tweets_urlDF = []
+	mentionsDF = []
+	text_tweetsDF = []
+	fav_twDF= []
+	ret_twDF = []
+	ret_twDF_list = []
+	fav_twDF_list = []
+	ntwPro_DF= []
+	RT_tw = []
+	minu_tw = []
+	minu_tw_answer = []
+	tw_duplicated = []
+	duplicated = []
+	tw_per_day_list= []
+	screen_name_mention_user = []
+	tweets = []
+	tweets_url = 0
+	num_tw_day = 1
+	is_RT=0
+	is_RT_list= []
+	screen_name_mention = []
+	RT = []
+	retweet_list = []
+	favorite_list = []
+	mentions = 0
+	time_btw_tw = []
+	tw_answer = []
+	num_tw_days = []
+	text_duplicated = []
+	tw_day_list = []
+	text_tweets_day = []
+	text_tweets_days = []
+	text_tweets_days_list = []
+	#Almacenar la fecha entera de los tweets para si hay que consultar las horas de ese dia
+	tweet_date_day = []
+	tweet_date_days = []
+	tweet_date_days_list = []
+	lang_text_tweet = list(data_tweets["lang_tw"])
+	text_tweets_user= list(data_tweets["text"])
+	print(len(text_tweets_user))
+	favorites= list(data_tweets["favorites"])
+	retweets = list(data_tweets["retweets"])
+	tweets_date= pd.to_datetime(data_tweets["created_at_tw"])
+	for j in range(len(text_tweets_user)): #Comprobamos cuantos tweets han sido escritos por el usuario 
+		if(text_tweets_user[j].startswith('RT',0)):
+			RT.append(text_tweets_user[j])
+			is_RT = 1
+		else:
+			is_RT=0          
+			#Tweets with url from users
+			if "http" in text_tweets_user[j]:
+				tweets_url = tweets_url + 1
+			#Tweets with mentions from users
+			if "@" in text_tweets_user[j]:
+				mentions = mentions + 1                        
+			else:
+				#Time of the answer of a tweet(tw --> @)
+				if(j!=(len(text_tweets_user)-1)):
+					if ("@" in text_tweets_user[j+1]):
+						tw_answer.append((tweets_date[j] - tweets_date[j+1]) / np.timedelta64(1,'m'))
+				#Found duplicated tweets where the only change the photo  that the users publish
+				text_sinHttp = " ".join(filter(lambda x:x[0:4]!='http', text_tweets_user[j].split()))
+				text_sinMencion = " ".join(filter(lambda x:x[0]!='@', text_sinHttp.split()))
+				text_duplicated.append(text_sinMencion)
+			tweets.append({"text":text_tweets_user[j], "lang": lang_text_tweet[j], "RT": 0})
+			retweet_list.append(int(retweets[j]))
+			favorite_list.append(int(favorites[j]))
+		is_RT_list.append(is_RT)                                
+		if(j!=0):
+			#Time between tweets (RT + propios)
+			time_btw_tw.append((tweets_date[j-1] - tweets_date[j]) / np.timedelta64(1,'m'))
+			#Found if tweets are the same day
+			#Second condition if all the tweets are the same day          
+			if((tweets_date[j-1].date() == tweets_date[j].date()) & (j!=(len(text_tweets_user)-1))):                            
+				num_tw_day = num_tw_day + 1
+				#Create a list with the tweets of a day
+				text_tweets_day.append({"text": text_tweets_user[j-1],"lang": lang_text_tweet[j-1],"RT": is_RT_list[j-1]})
+				text_tweets_day.append({"text": text_tweets_user[j],"lang": lang_text_tweet[j], "RT": is_RT_list[j]})              
+				tweet_date_day.append(tweets_date[j-1])
+				tweet_date_day.append(tweets_date[j])                         
+			else:
+				if(j==(len(text_tweets_user)-1)):                  
+					if(tweets_date[j-1].date() == tweets_date[j].date()):                     
+						text_tweets_day.append({"text": text_tweets_user[j-1],"lang": lang_text_tweet[j-1],"RT": is_RT_list[j-1]})
+						text_tweets_day.append({"text": text_tweets_user[j],"lang": lang_text_tweet[j], "RT": is_RT_list[j]})              
+						tweet_date_day.append(tweets_date[j-1])
+						tweet_date_day.append(tweets_date[j])
+						num_tw_day = num_tw_day + 1                      
+						text_tweets_days.append([i for n, i in enumerate(text_tweets_day) if i not in text_tweets_day[n + 1:]] )
+						tweet_date_days.append(list(dict.fromkeys(tweet_date_day)))
+						num_tw_days.append(len(list(dict.fromkeys(tweet_date_day))))
+						num_tw_day = 1 
+						text_tweets_day = []
+						tweet_date_day = []
+					else:                      
+						text_tweets_day.append({"text": text_tweets_user[j-1],"lang": lang_text_tweet[j-1],"RT": is_RT_list[j-1]})                                   
+						tweet_date_day.append(tweets_date[j-1]) 
+						num_tw_days.append(1)                     
+						text_tweets_days.append([i for n, i in enumerate(text_tweets_day) if i not in text_tweets_day[n + 1:]])
+						tweet_date_days.append(list(dict.fromkeys(tweet_date_day)))
+						text_tweets_day = []
+						tweet_date_day = []                      
+						tweet_date_day.append(tweets_date[j])                     
+						text_tweets_day.append({"text": text_tweets_user[j],"lang": lang_text_tweet[j], "RT": is_RT_list[j]}) 
+						num_tw_days.append(1)
+						text_tweets_days.append([i for n, i in enumerate(text_tweets_day) if i not in text_tweets_day[n + 1:]] )
+						tweet_date_days.append(list(dict.fromkeys(tweet_date_day)))
+						num_tw_day = 1 
+						text_tweets_day = []
+						tweet_date_day = []                      
+				else:
+					if(num_tw_day ==1):
+						text_tweets_day.append({"text": text_tweets_user[j-1],"lang": lang_text_tweet[j-1],"RT": is_RT_list[j-1]})
+						tweet_date_day.append(tweets_date[j-1])                  
+					text_tweets_days.append([i for n, i in enumerate(text_tweets_day) if i not in text_tweets_day[n + 1:]] )
+					tweet_date_days.append(list(dict.fromkeys(tweet_date_day)))
+					num_tw_days.append(len(list(dict.fromkeys(tweet_date_day))))
+					num_tw_day = 1 
+					text_tweets_day = []
+					tweet_date_day = []
+		if "@" in (text_tweets_user[j]):
+			split_text = text_tweets_user[j].split()
+			check = "@"
+			screen_name_mention1 = [idx for idx in split_text if idx.lower().startswith(check.lower())] 
+			if not screen_name_mention1:
+				screen_name_mention.append(["Empty"])
+			else:
+				screen_name_mention1 = re.sub("[\[\]\'\"!@?¿#$:….,]", '',str(screen_name_mention1)).split(", ")
+				if(text_tweets_user[j].startswith('RT',0)):
+					screen_name_mention.append([screen_name_mention1[0]])                    
+				else:
+					screen_name_mention.append(screen_name_mention1)
+		else:
+			screen_name_mention.append(["Empty"])
 
-    if(len(set(text_duplicated)) != len((text_duplicated))):
-        duplicated.append(len(text_duplicated) - len(set(text_duplicated)))
-    else:
-        duplicated.append(0)
+	if(len(set(text_duplicated)) != len((text_duplicated))):
+		duplicated.append(len(text_duplicated) - len(set(text_duplicated)))
+	else:
+		duplicated.append(0)
     
-    #Maximun tweets for user
-    if not num_tw_days:
-        text_tweets_days_list.append([{"text":"Empty", "lang":"und","RT":2}])
-        tweet_date_days_list.append(["Empty"])
-        tw_per_day_list.append([0])
-    else:
-        text_tweets_days_list.append(text_tweets_days)
-        tweet_date_days_list.append(tweet_date_days)
-        tw_per_day_list.append(num_tw_days)
-   
-    tw_day_list.append(list(sorted(set(tweets_date.dt.date), reverse=True)))
-    screen_name_mention_user.append(screen_name_mention)
-    seasonalityDF.append(np.std(time_btw_tw))
-    tweets_urlDF.append(tweets_url)
-    mentionsDF.append(mentions)
-    text_tweetsDF.append(tweets)
-    fav_twDF_list.append(favorite_list)
-    ret_twDF_list.append(retweet_list)
-    fav_twDF.append(int(sum(favorite_list)))
-    ret_twDF.append(int(sum(retweet_list)))
-    ntwPro_DF.append(int(len(tweets)))
-    RT_tw.append(int(len(RT)))
-    minu_tw.append(int(sum(time_btw_tw)))
-    #Time between tweets and its answer
-    if not tw_answer:
-        minu_tw_answer.append(0)
-    else:   
-        minu_tw_answer.append(int(sum(tw_answer))/len(tw_answer))
+	#Maximun tweets for user
+	if not num_tw_days:
+		text_tweets_days_list.append([{"text":"Empty", "lang":"und","RT":2}])
+		tweet_date_days_list.append(["Empty"])
+		tw_per_day_list.append([0])
+	else:
+		text_tweets_days_list.append(text_tweets_days)
+		tweet_date_days_list.append(tweet_date_days)
+		tw_per_day_list.append(num_tw_days)
+
+	tw_day_list.append(list(sorted(set(tweets_date.dt.date), reverse=True)))
+	screen_name_mention_user.append(screen_name_mention)
+	seasonalityDF.append(np.std(time_btw_tw))
+	tweets_urlDF.append(tweets_url)
+	mentionsDF.append(mentions)
+	text_tweetsDF.append(tweets)
+	fav_twDF_list.append(favorite_list)
+	ret_twDF_list.append(retweet_list)
+	fav_twDF.append(int(sum(favorite_list)))
+	ret_twDF.append(int(sum(retweet_list)))
+	ntwPro_DF.append(int(len(tweets)))
+	RT_tw.append(int(len(RT)))
+	minu_tw.append(int(sum(time_btw_tw)))
+	#Time between tweets and its answer
+	if not tw_answer:
+		minu_tw_answer.append(0)
+	else:   
+		minu_tw_answer.append(int(sum(tw_answer))/len(tw_answer))
         
-    return [screen_name_mention_user,seasonalityDF,tweets_urlDF,mentionsDF,text_tweetsDF,
-            fav_twDF_list,ret_twDF_list,fav_twDF,ret_twDF,RT_tw,ntwPro_DF,minu_tw,tw_per_day_list,
-            text_tweets_days_list,tweet_date_days_list,duplicated,minu_tw_answer,tw_day_list]
+	return [screen_name_mention_user,seasonalityDF,tweets_urlDF,mentionsDF,text_tweetsDF,
+			fav_twDF_list,ret_twDF_list,fav_twDF,ret_twDF,RT_tw,ntwPro_DF,minu_tw,tw_per_day_list,
+			text_tweets_days_list,tweet_date_days_list,duplicated,minu_tw_answer,tw_day_list]
 
 def time_twitter_account(df):
 
